package gregapi.data;

import gregapi.code.TagData;

/**
 * @author Gregorius Techneticies
 * 
 * List of all default Tag Data. The Short Name is for ease of overview and stands for "Tag Data".
 */
public class TD {
	/** For NEI and Creative Mode Menus */
	public static class Creative {
		/** If this Item, Prefix or Material is hidden from Creative (unless Debug Mode is on) */
		public static final TagData HIDDEN									= TagData.createTagData("NEI.HIDDEN");
	}
	
	/** For NEI and Creative Mode Menus */
	public static class Projectiles {
		public static final TagData ARROW									= TagData.createTagData("PROJECTILES.ARROW");
	}
	
	/** For Energy Systems. You can create your own kind of Energy too of course, but I have added some Defaults in order to make things simpler. */
	public static class Energy {
		/**
		 * Energy Tag for Electricity. Units are IndustrialCraft EU.
		 * Size = Voltage
		 * Amount = Amperage
		 */
		public static final TagData ELECTRICITY								= TagData.createTagData("ENERGY.ELECTRICITY"), EU = ELECTRICITY;
		
		/**
		 * Energy Tag for Rotation Power. Units are IndustrialCraft EU (yes EU for easier conversion).
		 * Size = Speed, Positive = Clockwise, Negative = Counter Clockwise
		 * Amount = Power
		 */
		public static final TagData KINETIC_ROTATION						= TagData.createTagData("ENERGY.KINETIC_ROTATION"), RU = KINETIC_ROTATION;
		
		/**
		 * Energy Tag for Piston Power. Units are IndustrialCraft EU (yes EU for easier conversion).
		 * Size = unused (always 1)
		 * Amount = Power
		 */
		public static final TagData KINETIC_PUSH							= TagData.createTagData("ENERGY.KINETIC_PUSH"), KU = KINETIC_PUSH;
		
		/**
		 * Energy Tag for Heat. Units are IndustrialCraft EU (yes EU for easier conversion).
		 * Size = unused (always 1)
		 * Amount = Temperature
		 */
		public static final TagData HEAT									= TagData.createTagData("ENERGY.HEAT"), HU = HEAT;
		
		/**
		 * Energy Tag for Lasers and alike. Units are IndustrialCraft EU (yes EU for easier conversion).
		 * Size = Strength/Size/Diameter/etc. of the Beam.
		 * Amount = Amount of Energy Transmitted (Frequency).
		 */
		public static final TagData LIGHT									= TagData.createTagData("ENERGY.LIGHT"), LU = LIGHT;
		
		/**
		 * Energy Tag for RedstoneFlux. Units are ThermalExpansion RastaFarians. 4 RF = 1 EU; 10 RF = 1 MJ;
		 * Size = unused (always 1)
		 * Amount = RF
		 */
		public static final TagData REDSTONE_FLUX							= TagData.createTagData("ENERGY.REDSTONE_FLUX"), RF = REDSTONE_FLUX;
		
		/**
		 * Energy Tag for MinecraftJoules. Units are BuildCraft MichaelJacksons. 1 MJ = 2.5 EU = 10 RF;
		 * Size = The Amount the Engine outputs in one push.
		 * Amount = MJ
		 */
		public static final TagData MINECRAFT_JOULES						= TagData.createTagData("ENERGY.MINECRAFT_JOULES"), MJ = MINECRAFT_JOULES;
		
		/**
		 * Energy Tag for Steam Power. Units are Litres of Steam.
		 * Size = unused (always 1)
		 * Amount = Steam per Tick
		 */
		public static final TagData STEAM									= TagData.createTagData("ENERGY.STEAM");
		
		/**
		 * Energy Tag for Air Pressure Power
		 * Size = Pressure
		 * Amount = Amount of Air
		 */
		public static final TagData AIR										= TagData.createTagData("ENERGY.AIR");
		
		/** Energy Tag for Ordo Vis */
		public static final TagData VIS_ORDO								= TagData.createTagData("ENERGY.VIS_ORDO");
		/** Energy Tag for Aer Vis */
		public static final TagData VIS_AER									= TagData.createTagData("ENERGY.VIS_AER");
		/** Energy Tag for Aqua Vis */
		public static final TagData VIS_AQUA								= TagData.createTagData("ENERGY.VIS_AQUA");
		/** Energy Tag for Terra Vis */
		public static final TagData VIS_TERRA								= TagData.createTagData("ENERGY.VIS_TERRA");
		/** Energy Tag for Ignis Vis */
		public static final TagData VIS_IGNIS								= TagData.createTagData("ENERGY.VIS_IGNIS");
		/** Energy Tag for Perditio Vis */
		public static final TagData VIS_PERDITIO							= TagData.createTagData("ENERGY.VIS_PERDITIO");
	}
	
	/** For Prefixes */
	public static class Prefix {
		/** If this Prefix is a Container */
		public static final TagData IS_CONTAINER							= TagData.createTagData("PREFIX.IS_CONTAINER");
		/** If this Prefix is Material Based */
		public static final TagData MATERIAL_BASED							= TagData.createTagData("PREFIX.MATERIAL_BASED");
		/** If this Prefix is normally used for Blocks */
		public static final TagData BLOCK_BASED								= TagData.createTagData("PREFIX.BLOCK_BASED");
		/** If this Prefix is Unificatable in Inventory */
		public static final TagData UNIFICATABLE							= TagData.createTagData("PREFIX.UNIFICATABLE");
		/** If this Prefix is only Unificatable in Recipes */
		public static final TagData UNIFICATABLE_RECIPES					= TagData.createTagData("PREFIX.UNIFICATABLE_RECIPES");
		/** If this Prefix is used for Ore Processing, like "crushed" for example */
		public static final TagData ORE_PROCESSING_BASED					= TagData.createTagData("PREFIX.ORE_PROCESSING_BASED");
		/** If this Prefix is for Tools and alike */
		public static final TagData TOOL_ALIKE								= TagData.createTagData("PREFIX.TOOL_ALIKE");
		/** If this Prefix is for Weapons and alike */
		public static final TagData WEAPON_ALIKE							= TagData.createTagData("PREFIX.WEAPON_ALIKE");
		/** If this Prefix is for Armors and alike */
		public static final TagData ARMOR_ALIKE								= TagData.createTagData("PREFIX.ARMOR_ALIKE");
		/** If this Prefix can be recycled */
		public static final TagData RECYCLABLE								= TagData.createTagData("PREFIX.RECYCLABLE");
		/** If this Prefix is self referencing and therefore needs no Material (it can still have a Material) */
		public static final TagData SELF_REFERENCING						= TagData.createTagData("PREFIX.SELF_REFERENCING");
	}
	
	/** For Atomic Materials */
	public static class Atomic {
		/** If this Material is an Atomic Element (Antimatter Elements include this too!) */
		public static final TagData ELEMENT									= TagData.createTagData("ATOMIC.ELEMENT");
		/** If this Material is an Atomic Particle */
		public static final TagData PARTICLE								= TagData.createTagData("ATOMIC.PARTICLE");
		/** If this Material is a Molecule, as opposed to being just random Materials mixed together. */
		public static final TagData MOLECULE								= TagData.createTagData("ATOMIC.MOLECULE");
		/** If this Material is Antimatter (Antimatter Molecules include this too!) */
		public static final TagData ANTIMATTER								= TagData.createTagData("ATOMIC.ANTIMATTER");
		
		/** If this Material is some kind of Metal (so added if any of the six Types below is the case!) */
		public static final TagData METAL									= TagData.createTagData("ATOMIC.METAL");
		/** If this Material is an Alkali Metal according to the periodic Table of Elements */
		public static final TagData ALKALI_METAL							= TagData.createTagData("ATOMIC.ALKALI_METAL");
		/** If this Material is an Alkaline Earth Metal according to the periodic Table of Elements */
		public static final TagData ALKALINE_EARTH_METAL					= TagData.createTagData("ATOMIC.ALKALINE_EARTH_METAL");
		/** If this Material is of the Lanthanide Group according to the periodic Table of Elements */
		public static final TagData LANTHANIDE								= TagData.createTagData("ATOMIC.LANTHANIDE");
		/** If this Material is of the Actinide Group according to the periodic Table of Elements */
		public static final TagData ACTINIDE								= TagData.createTagData("ATOMIC.ACTINIDE");
		/** If this Material is a Transition Metal according to the periodic Table of Elements */
		public static final TagData TRANSITION_METAL						= TagData.createTagData("ATOMIC.TRANSITION_METAL");
		/** If this Material is a Post Transition Metal according to the periodic Table of Elements */
		public static final TagData POST_TRANSITION_METAL					= TagData.createTagData("ATOMIC.POST_TRANSITION_METAL");
		
		/** If this Material is Metalloid according to the periodic Table of Elements */
		public static final TagData METALLOID								= TagData.createTagData("ATOMIC.METALLOID");
		
		/** If this Material is some kind of Nonmetal (so added if any of the three Types below is the case!) */
		public static final TagData NONMETAL								= TagData.createTagData("ATOMIC.NONMETAL");
		/** If this Material is a Polyatomic Nonmetal according to the periodic Table of Elements */
		public static final TagData POLYATOMIC_NONMETAL						= TagData.createTagData("ATOMIC.POLYATOMIC_NONMETAL");
		/** If this Material is a Diatomic Nonmetal according to the periodic Table of Elements */
		public static final TagData DIATOMIC_NONMETAL						= TagData.createTagData("ATOMIC.DIATOMIC_NONMETAL");
		/** If this Material is a Noble Gas according to the periodic Table of Elements */
		public static final TagData NOBLE_GAS								= TagData.createTagData("ATOMIC.NOBLE_GAS");
	}
	
	/** General Material Properties */
	public static class Properties {
		/** If this Material is some kind of Wood */
		public static final TagData WOOD									= TagData.createTagData("PROPERTIES.WOOD");
		/** If this Material is some kind of Food (or edible at all) */
		public static final TagData FOOD									= TagData.createTagData("PROPERTIES.FOOD");
		/** If this Material is some kind of Stone */
		public static final TagData STONE									= TagData.createTagData("PROPERTIES.STONE");
		/** If this Material is some kind of Pearl */
		public static final TagData PEARL									= TagData.createTagData("PROPERTIES.PEARL");
		/** If this Material is some kind of Quartz */
		public static final TagData QUARTZ									= TagData.createTagData("PROPERTIES.QUARTZ");
		/** If this Material is some kind of Crystal */
		public static final TagData CRYSTAL									= TagData.createTagData("PROPERTIES.CRYSTAL");
		/** If this Material is some kind of Magical */
		public static final TagData MAGICAL									= TagData.createTagData("PROPERTIES.MAGICAL");
		/** If this Material is having a constantly burning Aura (like Blaze Rods) */
		public static final TagData BURNING									= TagData.createTagData("PROPERTIES.BURNING");
		/** If this Material is some kind of flammable */
		public static final TagData FLAMMABLE								= TagData.createTagData("PROPERTIES.FLAMMABLE");
		/** If this Material is not burnable at all or Fire Proof */
		public static final TagData UNBURNABLE								= TagData.createTagData("PROPERTIES.UNBURNABLE");
		/** If this Material is some kind of explosive */
		public static final TagData EXPLOSIVE								= TagData.createTagData("PROPERTIES.EXPLOSIVE");
		/** If this Material is bouncy */
		public static final TagData BOUNCY									= TagData.createTagData("PROPERTIES.BOUNCY");
		/** If this Material is brittle */
		public static final TagData BRITTLE									= TagData.createTagData("PROPERTIES.BRITTLE");
		/** If this Material is stretchable */
		public static final TagData STRETCHY								= TagData.createTagData("PROPERTIES.STRETCHY");
		/** If this Material is invisible */
		public static final TagData INVISIBLE								= TagData.createTagData("PROPERTIES.INVISIBLE");
		/** If this Material is transparent */
		public static final TagData TRANSPARENT								= TagData.createTagData("PROPERTIES.TRANSPARENT");
		/** If this Material is Ender Dragon Proof. */
		public static final TagData ENDER_DRAGON_PROOF						= TagData.createTagData("PROPERTIES.ENDER_DRAGON_PROOF");
		/** If this Material is Wither Proof. */
		public static final TagData WITHER_PROOF							= TagData.createTagData("PROPERTIES.WITHER_PROOF");
		/** If this Material has a Color */
		public static final TagData HAS_TOOL_STATS							= TagData.createTagData("PROPERTIES.HAS_TOOL_STATS");
		/** If this Material has a Color */
		public static final TagData HAS_COLOR								= TagData.createTagData("PROPERTIES.HAS_COLOR");
		/** If this Material is only Unificatable in Recipes (for example Wood, which has many variations depending on from which Tree it comes from) */
		public static final TagData AUTO_BLACKLIST							= TagData.createTagData("PROPERTIES.AUTO_BLACKLIST");
		/** If this Material is not a valid Material Name and therefore doesn't get unificated at all. This mainly gets used for technical Materials. */
		public static final TagData INVALID_MATERIAL						= TagData.createTagData("PROPERTIES.INVALID_MATERIAL");
		/** If this Material should not be shown with the Contains X Tooltip. */
		public static final TagData DONT_SHOW_THIS_COMPONENT				= TagData.createTagData("PROPERTIES.DONT_SHOW_THIS_COMPONENT");
	}
	
	/** Describing the kind of binding the Compound Material is having */
	public static class Compounds {
		/** If this Material is some kind of Metallurgic Alloy (For Mods which automatically create Alloys in Smelteries or similar if the Components are there) */
		public static final TagData ALLOY									= TagData.createTagData("COMPOUNDS.ALLOY");
		
		/** If this Material is only vaguely decomposable. An example for that would be Gravel, Dirt or Clay, where no one knows the exact Components or hidden things. */
		public static final TagData APPROXIMATE								= TagData.createTagData("COMPOUNDS.APPROXIMATE");
		
		/** If this Material is decomposable by any means. This must be added when the Material can be reversed by any means, to prevent people from making it acquirable by cheaper means, causing exploits. */
		public static final TagData DECOMPOSABLE							= TagData.createTagData("COMPOUNDS.DECOMPOSABLE");
	}
	
	/** For Material Processing */
	public static class Processing {
		/** If this Material is not recyclable in the IC2 Recycler or similar. This means it is blacklisted automatically.  */
		public static final TagData UNRECYCLABLE							= TagData.createTagData("PROCESSING.UNRECYCLABLE");
		/** If this Material is decomposable by a Centrifuge. Requires Compounds.DECOMPOSABLE too */
		public static final TagData CENTRIFUGE								= TagData.createTagData("PROCESSING.CENTRIFUGABLE");
		/** If this Material is decomposable by an Electrolyser. Requires Compounds.DECOMPOSABLE too */
		public static final TagData ELECTROLYSER							= TagData.createTagData("PROCESSING.ELECTROLYSABLE");
		/** If this Material can be created using UU-Matter or UU-Anti-Matter respectively */
		public static final TagData UUM										= TagData.createTagData("PROCESSING.UUM_SYNTHESISABLE");
		/** If this Material can be created using Nuclear Fusion */
		public static final TagData FUSION									= TagData.createTagData("PROCESSING.FUSION_SYNTHESISABLE");
		/** If this Material can be ground by a Mortar. */
		public static final TagData MORTAR									= TagData.createTagData("PROCESSING.MORTAR_GRINDABLE");
		
		public static final TagData SMITHABLE								= TagData.createTagData("PROCESSING.SMITHABLE");
		/** If this Material can be directly cooked in a regular Furnace */
		public static final TagData FURNACE									= TagData.createTagData("PROCESSING.FURNACE");
		/** If this Material can be molten in an Oven */
		public static final TagData MELTING									= TagData.createTagData("PROCESSING.MELTING");
		
		public static final TagData CRYSTALLISABLE							= TagData.createTagData("PROCESSING.CRYSTALLISABLE");
		
		public static final TagData SOLDERING_MATERIAL						= TagData.createTagData("PROCESSING.SOLDERING_MATERIAL");
		public static final TagData SOLDERING_MATERIAL_BAD					= TagData.createTagData("PROCESSING.SOLDERING_MATERIAL_BAD");
		public static final TagData SOLDERING_MATERIAL_GOOD					= TagData.createTagData("PROCESSING.SOLDERING_MATERIAL_GOOD");
		
		public static final TagData ELECTROMAGNETIC_SEPERATION_NEODYMIUM	= TagData.createTagData("PROCESSING.ELECTROMAGNETIC_SEPERATION_NEODYMIUM");
		public static final TagData ELECTROMAGNETIC_SEPERATION_GOLD			= TagData.createTagData("PROCESSING.ELECTROMAGNETIC_SEPERATION_GOLD");
		public static final TagData ELECTROMAGNETIC_SEPERATION_IRON			= TagData.createTagData("PROCESSING.ELECTROMAGNETIC_SEPERATION_IRON");
		public static final TagData BLASTFURNACE_CALCITE_DOUBLE				= TagData.createTagData("PROCESSING.BLASTFURNACE_CALCITE_DOUBLE");
		public static final TagData BLASTFURNACE_CALCITE_TRIPLE				= TagData.createTagData("PROCESSING.BLASTFURNACE_CALCITE_TRIPLE");
		public static final TagData WASHING_SODIUMPERSULFATE				= TagData.createTagData("PROCESSING.WASHING_SODIUMPERSULFATE");
		public static final TagData WASHING_MERCURY							= TagData.createTagData("PROCESSING.WASHING_MERCURY");
		public static final TagData PULVERIZING_CINNABAR					= TagData.createTagData("PROCESSING.PULVERIZING_CINNABAR");
	}
	
	/** For Materials and the Item Generator */
	public static class ItemGenerator {
		/** For Materials and the Item Generator */
		public static final TagData
		GEMS																= TagData.createTagData("ITEMGENERATOR.GEMS"),
		ORES																= TagData.createTagData("ITEMGENERATOR.ORES"),
		EMPTY																= TagData.createTagData("ITEMGENERATOR.EMPTY"),
		DUSTS																= TagData.createTagData("ITEMGENERATOR.DUSTS"),
		TOOLS																= TagData.createTagData("ITEMGENERATOR.TOOLS"),
		PARTS																= TagData.createTagData("ITEMGENERATOR.PARTS"),
		PIPES																= TagData.createTagData("ITEMGENERATOR.PIPES"),
		WIRES																= TagData.createTagData("ITEMGENERATOR.WIRES"),
		LENSES																= TagData.createTagData("ITEMGENERATOR.LENSES"),
		STICKS																= TagData.createTagData("ITEMGENERATOR.STICKS"),
		ARMORS																= TagData.createTagData("ITEMGENERATOR.ARMORS"),
		INGOTS																= TagData.createTagData("ITEMGENERATOR.INGOTS"),
		PLATES																= TagData.createTagData("ITEMGENERATOR.PLATES"),
		WEAPONS																= TagData.createTagData("ITEMGENERATOR.WEAPONS"),
		CONTAINERS															= TagData.createTagData("ITEMGENERATOR.CONTAINERS"),
		DIRTY_DUSTS															= TagData.createTagData("ITEMGENERATOR.DIRTY_DUSTS"),
		MULTIINGOTS															= TagData.createTagData("ITEMGENERATOR.MULTIINGOTS"),
		MULTIPLATES															= TagData.createTagData("ITEMGENERATOR.MULTIPLATES"),
		DENSEPLATES															= TagData.createTagData("ITEMGENERATOR.DENSEPLATES"),
		CONTAINERS_GAS														= TagData.createTagData("ITEMGENERATOR.CONTAINERS_GAS"),
		CONTAINERS_SOLID													= TagData.createTagData("ITEMGENERATOR.CONTAINERS_SOLID"),
		CONTAINERS_FLUID													= TagData.createTagData("ITEMGENERATOR.CONTAINERS_FLUID"),
		CONTAINERS_PLASMA													= TagData.createTagData("ITEMGENERATOR.CONTAINERS_PLASMA");
		
		/** Item Generator Presets as Shortcut */
		public static final TagData[]
		G_ALL						= new TagData[] {GEMS, ORES, EMPTY, DUSTS, TOOLS, PARTS, PIPES, WIRES, LENSES, STICKS, ARMORS, INGOTS, PLATES, WEAPONS, CONTAINERS, DIRTY_DUSTS, MULTIINGOTS, MULTIPLATES, DENSEPLATES, CONTAINERS_GAS, CONTAINERS_SOLID, CONTAINERS_FLUID, CONTAINERS_PLASMA},
		G_DUST						= new TagData[] {DUSTS},
		G_DUST_ORES					= new TagData[] {DUSTS, DIRTY_DUSTS, ORES},
		G_CRYSTAL					= new TagData[] {DUSTS, GEMS},
		G_CRYSTAL_ORES				= new TagData[] {DUSTS, GEMS, DIRTY_DUSTS, ORES},
		G_BLAZE						= new TagData[] {DUSTS, STICKS, WEAPONS, TOOLS},
		G_PEARL						= new TagData[] {DUSTS, PLATES, GEMS},
		G_PEARL_TRANSPARENT			= new TagData[] {DUSTS, PLATES, GEMS, LENSES, TD.Properties.TRANSPARENT},
		G_QUARTZ					= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, GEMS},
		G_QUARTZ_ORES				= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, GEMS, DIRTY_DUSTS, ORES},
		G_GEM						= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, GEMS, ARMORS},
		G_GEM_ORES					= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, GEMS, ARMORS, DIRTY_DUSTS, ORES},
		G_GEM_TRANSPARENT			= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, GEMS, ARMORS, LENSES, TD.Properties.TRANSPARENT},
		G_GEM_ORES_TRANSPARENT		= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, GEMS, ARMORS, LENSES, TD.Properties.TRANSPARENT, DIRTY_DUSTS, ORES},
		G_STONE						= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, DIRTY_DUSTS},
		G_WOOD						= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, STICKS},
		G_INGOT						= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, STICKS, ARMORS, INGOTS, MULTIINGOTS, DENSEPLATES, MULTIPLATES},
		G_INGOT_ORES				= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, STICKS, ARMORS, INGOTS, MULTIINGOTS, DENSEPLATES, MULTIPLATES, DIRTY_DUSTS, ORES},
		G_INGOT_MACHINE				= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, STICKS, ARMORS, INGOTS, MULTIINGOTS, DENSEPLATES, MULTIPLATES, PARTS},
		G_INGOT_MACHINE_ORES		= new TagData[] {DUSTS, PLATES, WEAPONS, TOOLS, STICKS, ARMORS, INGOTS, MULTIINGOTS, DENSEPLATES, MULTIPLATES, PARTS, DIRTY_DUSTS, ORES};
	}
}